==> jc-1.4.0.tar.gz: gnu/java/rmi/dgc/DGCImpl__24LeaseRecord.h <==
// class gnu.java.rmi.dgc.DGCImpl$LeaseRecord

// class file dependencies
// @dep_class b118491394826462 gnu_java_rmi_dgc_DGCImpl__24LeaseRecord
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord_H_
#define _JC_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_dgc_VMID$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object;

typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype;

// Constructors
extern void _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method$_init$10b3f25b475f38f7(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *, struct _jc_java_rmi_dgc_VMID$object *, jlong);

// Virtual methods
extern jboolean _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method$isExpired$52109f572fec83ce(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *);
extern void _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method$reset$1a19e15e2f6ad0ff(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method_info$isExpired$52109f572fec83ce;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method_info$reset$1a19e15e2f6ad0ff;

// Virtual methods structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods {
	jboolean	(*isExpired$52109f572fec83ce)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *);
	void	(*reset$1a19e15e2f6ad0ff)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *, jlong);
};

// Vtable
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods	gnu_java_rmi_dgc_DGCImpl__24LeaseRecord;
};

// Vtype
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs {
	struct _jc_java_rmi_dgc_VMID$object	*vmid;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs {
    _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs	gnu_java_rmi_dgc_DGCImpl__24LeaseRecord;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs {
	jlong	expireTime;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs	gnu_java_rmi_dgc_DGCImpl__24LeaseRecord;
};

// Object instance structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object {
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype	*vtype;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_dgc_DGCImpl__24LeaseRecord, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$class_object;

#endif	/* _JC_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/dgc/DGCImpl__24LeaseRecord.h <==
// class gnu.java.rmi.dgc.DGCImpl$LeaseRecord

// class file dependencies
// @dep_class 1153678bdbb91bff gnu_java_rmi_dgc_DGCImpl__24LeaseRecord
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord_H_
#define _JC_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_dgc_VMID$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs;
typedef struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object;

typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable;
typedef const struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype;

// Constructors
extern void _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method$_init$10b3f25b475f38f7(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *, struct _jc_java_rmi_dgc_VMID$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method$isExpired$52109f572fec83ce(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method$reset$1a19e15e2f6ad0ff(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method_info$isExpired$52109f572fec83ce;
extern _jc_method _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$method_info$reset$1a19e15e2f6ad0ff;

// Virtual methods structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods {
	jboolean	(*isExpired$52109f572fec83ce)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *) _JC_JCNI_ATTR;
	void	(*reset$1a19e15e2f6ad0ff)(_jc_env *, struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vmethods	gnu_java_rmi_dgc_DGCImpl__24LeaseRecord;
};

// Vtype
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs {
	struct _jc_java_rmi_dgc_VMID$object	*vmid;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs {
    _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_refs	gnu_java_rmi_dgc_DGCImpl__24LeaseRecord;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs {
	jlong	expireTime;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$sub_nonrefs	gnu_java_rmi_dgc_DGCImpl__24LeaseRecord;
};

// Object instance structure
struct _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$object {
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype	*vtype;
	_jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$vtype _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_dgc_DGCImpl__24LeaseRecord, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord$class_object;

#endif	/* _JC_gnu_java_rmi_dgc_DGCImpl__24LeaseRecord_H_ */
